﻿namespace TabsStudioMarker
{
    public class Marker : TabsStudioExt.ITabsStudioAddin, TabsStudioExt.IStyler
    {
        public void OnConnection(TabsStudioExt.ITabsStudioEngine engine_, EnvDTE80.DTE2 dte)
        {
            engine = engine_;
            engine.TabCreated += OnTabCreated;
            engine.TabDestroyed += OnTabDestroyed;

            UpdatePresentationStyle();
        }

        public void OnDisconnection()
        {
            engine.TabCreated -= OnTabCreated;
            engine.TabDestroyed -= OnTabDestroyed;
        }

        public string GetNamespacesForResourceDictionary()
        {
            return "xmlns:TabsStudioMarker=\"clr-namespace:TabsStudioMarker;assembly=Marker\"";
        }

        private void OnTabCreated(object sender, TabsStudioExt.TabEventArgs e)
        {
            e.Tab.TabItem.MouseUp += OnClick;            
        }

        private void OnTabDestroyed(object sender, TabsStudioExt.TabEventArgs e)
        {
            e.Tab.TabItem.MouseUp -= OnClick;            
        }

        private void OnClick(object sender, System.Windows.Input.MouseButtonEventArgs e)
        {
            if ((System.Windows.Forms.Control.ModifierKeys & System.Windows.Forms.Keys.Control) != 0)
            {
                System.Windows.UIElement tabItem = sender as System.Windows.Controls.TabItem;
                Properties.SetIsHighlighted(tabItem, !Properties.GetIsHighlighted(tabItem));
            }
        }

        private void UpdatePresentationStyle()
        {
            TabsStudioExt.Presentation presentation = new TabsStudioExt.Presentation("", "");
            {
                TabsStudioExt.PresentationStyle style = new TabsStudioExt.PresentationStyle();
                style.Triggers.Add(LoadString("TabInternalsHighlighting.xml"));
                presentation.Styles.Add("TabsStudio:TabInternals", style);
            }
            engine.UpdatePresentationStyles("Marker", presentation);
        }

        private static string LoadString(string resource)
        {
            using (System.IO.Stream stream = System.Reflection.Assembly.GetExecutingAssembly().GetManifestResourceStream(
                "Marker." + resource))
            {
                using (System.IO.StreamReader reader = new System.IO.StreamReader(stream))
                {
                    return reader.ReadToEnd();
                }
            }
        }

        private TabsStudioExt.ITabsStudioEngine engine;
    }
}